@@ -7,8 +7,8 @@ Information about the current version of the py-package-template package.
 
 __title__ = 'odinwolf'
 __description__ = f'A wrapper for the {__title__} package.'
-__version__ = '1.1.4'
+__version__ = '1.1.6'
 __author__ = 'janus banus'
 __author_email__ = 'janus.banus@gmail.com'
 __license__ = 'Apache 2.0'
-__url__ = 'https://youtube.com'
+__url__ = 'https://youtube.com/'
